"""
A simple printer of nested list
"""

def print_lol(the_list, level):
    """
    This function ...
    """

    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level)
        else:
            for tab_stop in raneg(level):
                print("\t", end='')
            print(each_item)



from distutils.core import setup

setup(
    name = 'wang_nest',
    version = '1.1.0',
    py_modules = ['wang_nest'],
    author = 'wangyuan',
    author_email = 'wangyuanfu315@gmail.com',
    url = 'http://headfirstlabs.com',
    description = 'A simple printer of nested lists',

)
